==> typo3_src-9.5.14.tar.gz: typo3_src-9.5.14/typo3/sysext/extensionmanager/Classes/ViewHelpers/ProcessAvailableActionsViewHelper.php <==
<?php
namespace TYPO3\CMS\Extensionmanager\ViewHelpers;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper;

/**
 * ViewHelper to let 3rd-party extensions process the list of available
 * actions for a given extension.
 * @internal
 */
class ProcessAvailableActionsViewHelper extends AbstractTagBasedViewHelper
{
    const SIGNAL_ProcessActions = 'processActions';

    /**
     * @var \TYPO3\CMS\Extbase\SignalSlot\Dispatcher
     */
    protected $signalSlotDispatcher;

    /**
     * @param \TYPO3\CMS\Extbase\SignalSlot\Dispatcher $signalSlotDispatcher
     */
    public function injectSignalSlotDispatcher(\TYPO3\CMS\Extbase\SignalSlot\Dispatcher $signalSlotDispatcher)
    {
        $this->signalSlotDispatcher = $signalSlotDispatcher;
    }

    /**
     * Initialize arguments
     */
    public function initializeArguments()
    {
        parent::initializeArguments();
        $this->registerArgument('extension', 'string', '', true);
    }

    /**
     * Processes the list of actions.
     *
     * @return string the rendered list of actions
     */
    public function render()
    {
        $extension = $this->arguments['extension'];
        $html = $this->renderChildren();
        $actions = preg_split('#\\n\\s*#s', trim($html));

        $actions = $this->emitProcessActionsSignal($extension, $actions);

        return implode(' ', $actions);
    }

    /**
     * Emits a signal after the list of actions is processed
     *
     * @param string $extension
     * @param array $actions
     * @return array Modified action array
     */
    protected function emitProcessActionsSignal($extension, array $actions)
    {
        $this->signalSlotDispatcher->dispatch(
            __CLASS__,
            static::SIGNAL_ProcessActions,
            [
                $extension,
                &$actions,
            ]
        );
        return $actions;
    }
}

==> typo3_src-10.3.0.tar.gz: typo3_src-10.3.0/typo3/sysext/extensionmanager/Classes/ViewHelpers/ProcessAvailableActionsViewHelper.php <==
<?php
namespace TYPO3\CMS\Extensionmanager\ViewHelpers;

/*
 * This file is part of the TYPO3 CMS project.
 *
 * It is free software; you can redistribute it and/or modify it under
 * the terms of the GNU General Public License, either version 2
 * of the License, or any later version.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * The TYPO3 project - inspiring people to share!
 */

use Psr\EventDispatcher\EventDispatcherInterface;
use TYPO3\CMS\Extensionmanager\Event\AvailableActionsForExtensionEvent;
use TYPO3Fluid\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper;

/**
 * ViewHelper to let 3rd-party extensions process the list of available
 * actions for a given extension.
 * @internal
 */
class ProcessAvailableActionsViewHelper extends AbstractTagBasedViewHelper
{
    /**
     * @var EventDispatcherInterface
     */
    protected $eventDispatcher;

    public function injectEventDispatcher(EventDispatcherInterface $eventDispatcher)
    {
        $this->eventDispatcher = $eventDispatcher;
    }

    public function initializeArguments()
    {
        parent::initializeArguments();
        $this->registerArgument('extension', 'array', '', true);
    }

    /**
     * Processes the list of actions.
     *
     * @return string the rendered list of actions
     */
    public function render()
    {
        $html = $this->renderChildren();
        $actions = preg_split('#\\n\\s*#s', trim($html));

        $event = new AvailableActionsForExtensionEvent($this->arguments['extension']['key'], $this->arguments['extension'], $actions);
        $this->eventDispatcher->dispatch($event);
        return implode(' ', $event->getActions());
    }
}
